*******************************
The sherpa.astro.optical module
*******************************

.. currentmodule:: sherpa.astro.optical

.. automodule:: sherpa.astro.optical

   .. rubric:: Classes
               
   .. autosummary::
      :toctree: api
   
      AbsorptionEdge
      AbsorptionGaussian
      AbsorptionLorentz
      AbsorptionVoigt
      AccretionDisk
      BlackBody
      Bremsstrahlung
      BrokenPowerlaw
      CCM
      EmissionGaussian
      EmissionLorentz
      EmissionVoigt
      FM
      LMC
      LogAbsorption
      LogEmission
      OpticalGaussian
      Polynomial
      Powerlaw
      Recombination
      SM
      SMC
      Seaton
      XGal
   
Class Inheritance Diagram
=========================

.. inheritance-diagram:: AbsorptionEdge AbsorptionGaussian AbsorptionLorentz AbsorptionVoigt AccretionDisk BlackBody Bremsstrahlung BrokenPowerlaw CCM EmissionGaussian EmissionLorentz EmissionVoigt FM LMC LogAbsorption LogEmission OpticalGaussian Polynomial Powerlaw Recombination SM SMC Seaton XGal
   :parts: 1
   
